@@ -119,7 +119,7 @@ where
     fn elapsed(&mut self) -> Duration {
         self.input.elapsed()
     }
-    fn seek(&mut self, seek_time: Duration) -> Result<Duration, ()> {
+    fn seek(&mut self, seek_time: Duration) -> Option<Duration> {
         self.input.seek(seek_time)
     }
 }
