@@ -185,7 +185,7 @@ where
     fn elapsed(&mut self) -> Duration {
         self.input.elapsed()
     }
-    fn seek(&mut self, time: Duration) -> Result<Duration, ()> {
+    fn seek(&mut self, time: Duration) -> Option<Duration> {
         self.input.seek(time)
     }
 }
