@@ -186,7 +186,6 @@ impl Component<Msg, NoUserEvent> for GlobalListener {
 
 impl Model {
     /// global listener subscriptions
-    // #[allow(clippy::too_many_lines)]
     pub fn subscribe(keys: &Keys) -> Vec<Sub<Id, NoUserEvent>> {
         vec![
             Sub::new(
@@ -270,11 +269,20 @@ impl Model {
     }
     pub fn player_next(&mut self) {
         if self.playlist_items.is_empty() {
+            self.status = Status::Stopped;
+            self.player.stop();
+            if let Err(e) = self.update_photo() {
+                self.mount_error_popup(format!("update photo error: {}", e).as_str());
+            };
+            self.progress_update_title();
+            self.lyric_update_title();
+            self.update_lyric();
+            self.force_redraw();
             return;
         }
         self.time_pos = 0;
         // self.time_pos_elapsed = std::time::Instant::now();
-        self.status = Some(Status::Running);
+        self.status = Status::Running;
         if let Some(song) = self.playlist_items.pop_front() {
             if let Some(file) = song.file() {
                 self.player.add_and_play(file);
@@ -294,6 +302,7 @@ impl Model {
                 self.mount_error_popup(format!("update photo error: {}", e).as_str());
             };
             self.progress_update_title();
+            self.lyric_update_title();
             self.update_playing_song();
         }
     }
@@ -318,32 +327,42 @@ impl Model {
 
     pub fn player_toggle_pause(&mut self) {
         if self.player.is_paused() {
-            self.status = Some(Status::Running);
+            self.status = Status::Running;
             self.player.resume();
             #[cfg(feature = "mpris")]
             self.mpris.resume();
             #[cfg(feature = "discord")]
             self.discord.resume(self.time_pos);
         } else {
-            self.status = Some(Status::Paused);
+            self.status = Status::Paused;
             self.player.pause();
             #[cfg(feature = "mpris")]
             self.mpris.pause();
             #[cfg(feature = "discord")]
             self.discord.pause();
         }
+        self.progress_update_title();
     }
 
     pub fn player_seek(&mut self, offset: i64) {
+        // FIXME: dirty fix for seeking when paused with symphonia,basically set it to play
+        // in rusty sink code, and seek, and then set it back to pause.
+        #[cfg(not(any(feature = "mpv", feature = "gst")))]
+        let paused = self.player.is_paused();
+        #[cfg(not(any(feature = "mpv", feature = "gst")))]
+        if paused {
+            self.player.set_volume(0);
+        }
+
         self.player.seek(offset).ok();
-        // if let Ok((_, time_pos, _)) = self.player.get_progress() {
-        //     if let Some(t) = std::time::Instant::now()
-        //         .checked_sub(std::time::Duration::from_secs(time_pos.try_into().unwrap()))
-        //     {
-        //         self.time_pos_elapsed = t;
-        //     }
-        // }
-        self.progress_update();
+
+        #[cfg(not(any(feature = "mpv", feature = "gst")))]
+        if paused {
+            self.force_redraw();
+            std::thread::sleep(std::time::Duration::from_millis(50));
+            self.player.pause();
+            self.player.set_volume(self.config.volume);
+        }
     }
 }
 ///
