@@ -1,3 +1,4 @@
+use crate::config::Termusic;
 use crate::player::GeneralP;
 use crate::song::Song;
 // use crate::ui::Status;
@@ -5,8 +6,6 @@ use crate::ui::{Id, Model, Msg};
 // use std::thread::{self, sleep};
 // use std::thread::sleep;
 
-use crate::ui::components::StyleColorSymbol;
-use if_chain::if_chain;
 use std::time::Duration;
 use tui_realm_stdlib::ProgressBar;
 use tuirealm::event::NoUserEvent;
@@ -19,30 +18,39 @@ pub struct Progress {
 }
 
 impl Progress {
-    pub fn new(style_color_symbol: &StyleColorSymbol) -> Self {
+    pub fn new(config: &Termusic) -> Self {
         Self {
             component: ProgressBar::default()
                 .borders(
                     Borders::default()
                         .color(
-                            style_color_symbol
+                            config
+                                .style_color_symbol
                                 .progress_border()
                                 .unwrap_or(Color::LightMagenta),
                         )
                         .modifiers(BorderType::Rounded),
                 )
                 .background(
-                    style_color_symbol
+                    config
+                        .style_color_symbol
                         .progress_background()
                         .unwrap_or(Color::Reset),
                 )
                 .foreground(
-                    style_color_symbol
+                    config
+                        .style_color_symbol
                         .progress_foreground()
                         .unwrap_or(Color::Yellow),
                 )
-                .label("Song Name")
-                .title("Playing", Alignment::Center)
+                .label("Progress")
+                .title(
+                    format!(
+                        "Status: Stopped | Volume: {} | Speed: {:^.1} ",
+                        config.volume, config.speed,
+                    ),
+                    Alignment::Center,
+                )
                 .progress(0.0),
         }
     }
@@ -61,7 +69,7 @@ impl Model {
             .app
             .mount(
                 Id::Progress,
-                Box::new(Progress::new(&self.config.style_color_symbol)),
+                Box::new(Progress::new(&self.config)),
                 Vec::new()
             )
             .is_ok());
@@ -69,25 +77,19 @@ impl Model {
     }
 
     pub fn progress_update_title(&mut self) {
-        if_chain! {
-            if let Some(song) = &self.current_song;
-            let artist = song.artist().unwrap_or("Unknown Artist");
-            let title = song.title().unwrap_or("Unknown Title");
-            let progress_title = format!(
-                "Playing: {:^.20} - {:^.20} | Volume: {} | Speed: {:^.1} ",
-                            artist, title, self.config.volume, self.config.speed,
-                );
-            then {
-                self.app.attr( &Id::Progress,
-                    Attribute::Title,
-                    AttrValue::Title((progress_title,Alignment::Center)),
-                    ).ok();
-
-            }
-        }
+        let progress_title = format!(
+            "Status: {} | Volume: {} | Speed: {:^.1} ",
+            self.status, self.config.volume, self.config.speed,
+        );
+        self.app
+            .attr(
+                &Id::Progress,
+                Attribute::Title,
+                AttrValue::Title((progress_title, Alignment::Center)),
+            )
+            .ok();
     }
 
-    #[allow(clippy::cast_sign_loss)]
     pub fn progress_update(&mut self) {
         if let Ok((progress, time_pos, duration)) = self.player.get_progress() {
             // for unsupported file format, don't update progress
@@ -96,9 +98,6 @@ impl Model {
             }
 
             if time_pos >= duration {
-                // std::thread::sleep(Duration::from_millis(500));
-                // println!("{}--{}", time_pos, duration);
-                // self.status = Some(Status::Stopped);
                 self.player_next();
                 return;
             }
