@@ -95,6 +95,8 @@ pub enum PLMsg {
     LoopModeCycle,
     PlaySelected(usize),
     Shuffle,
+    SwapDown(usize),
+    SwapUp(usize),
 }
 #[derive(Clone, Debug, PartialEq)]
 pub enum GSMsg {
@@ -349,6 +351,14 @@ pub enum KEMsg {
     PlaylistSearchBlurUp,
     PlaylistSearchInputBlurDown,
     PlaylistSearchInputBlurUp,
+    PlaylistSwapDownBlurDown,
+    PlaylistSwapDownBlurUp,
+    PlaylistSwapDownInputBlurDown,
+    PlaylistSwapDownInputBlurUp,
+    PlaylistSwapUpBlurDown,
+    PlaylistSwapUpBlurUp,
+    PlaylistSwapUpInputBlurDown,
+    PlaylistSwapUpInputBlurUp,
     RadioOkBlurUp,
     RadioOkBlurDown,
 }
@@ -492,16 +502,29 @@ pub enum IdKeyEditor {
     PlaylistPlaySelectedInput,
     PlaylistAddFrontInput,
     PlaylistSearchInput,
+    PlaylistSwapDown,
+    PlaylistSwapDownInput,
+    PlaylistSwapUp,
+    PlaylistSwapUpInput,
     RadioOk,
 }
 
-#[derive(Clone, Copy)]
+#[derive(Clone, Copy, PartialEq)]
 pub enum Status {
     Running,
     Stopped,
     Paused,
 }
 
+impl std::fmt::Display for Status {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        match self {
+            Status::Running => write!(f, "Running"),
+            Status::Stopped => write!(f, "Stopped"),
+            Status::Paused => write!(f, "Paused"),
+        }
+    }
+}
 // StatusLine shows the status of download
 #[derive(Copy, Clone)]
 pub enum StatusLine {
@@ -530,9 +553,6 @@ impl Loop {
                 Self::Single => "🔂".to_string(),
                 Self::Playlist => "🔁".to_string(),
                 Self::Queue => "⬇".to_string(),
-                // Self::Single => "single",
-                // Self::Playlist => "playlist",
-                // Self::Queue => "consume",
             }
         } else {
             match self {
@@ -553,8 +573,6 @@ impl UI {
     pub fn new(config: &Termusic) -> Self {
         let mut model = Model::new(config);
         model.init_config();
-        // model.library_reload_tree();
-        // assert!(model.app.active(&Id::Library).is_ok());
         Self { model }
     }
     /// ### run
@@ -606,7 +624,6 @@ impl UI {
             // sleep(Duration::from_millis(20));
         }
         assert!(self.model.playlist_save().is_ok());
-        // assert!(self.model.config.save().is_ok());
         if let Err(e) = self.model.config.save() {
             eprintln!("{}", e);
         };
@@ -617,10 +634,10 @@ impl UI {
 
     fn check_force_redraw(&mut self) {
         // If source are loading and at least 100ms has elapsed since last redraw...
-        if let Some(Status::Running) = self.model.status {
-            if self.model.since_last_redraw() >= FORCED_REDRAW_INTERVAL {
-                self.model.force_redraw();
-            }
+        // if self.model.status == Status::Running {
+        if self.model.since_last_redraw() >= FORCED_REDRAW_INTERVAL {
+            self.model.force_redraw();
         }
+        // }
     }
 }
